from setuptools import setup

setup(name='sbad_distributions',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['sbad_distributions'],
      author ="Sergio Badillo",
      author_email = "sbadilloworks@gmail.com",
      zip_safe=False)
